src/pyams_default_theme/features/menu/portlet/navigation/__init__.py
changeset 55 ab81e4954e66
parent 49 25e09b2760e4
child 57 fc86c86eb416
--- a/src/pyams_default_theme/features/menu/portlet/navigation/__init__.py	Mon Jun 18 09:20:08 2018 +0200
+++ b/src/pyams_default_theme/features/menu/portlet/navigation/__init__.py	Mon Jun 18 09:27:59 2018 +0200
@@ -37,12 +37,22 @@
 @adapter_config(context=(IPortalContext, IPyAMSLayer, Interface, ISimpleNavigationPortletSettings),
                 provides=IPortletRenderer)
 @template_config(template='templates/simple-horizontal.pt', layer=IPyAMSLayer)
-class SimpleNavigationDefaultPortletRenderer(PortletRenderer):
-    """Simple navigation default portlet renderer"""
+class SimpleNavigationPortletHorizontalRenderer(PortletRenderer):
+    """Simple navigation horizontal portlet renderer"""
 
     label = _("Horizontal list with vertical illustrations")
 
 
+@adapter_config(name='horizontal-tabs',
+                context=(IPortalContext, IPyAMSLayer, Interface, ISimpleNavigationPortletSettings),
+                provides=IPortletRenderer)
+@template_config(template='templates/simple-horizontal-tabs.pt', layer=IPyAMSLayer)
+class SimpleNavigationPortletHorizontalTabsRenderer(PortletRenderer):
+    """Simple navigation horizontal portlet renderer with tabs"""
+
+    label = _("Horizontal list with tabs and horizontal illustrations")
+
+
 #
 # Double navigation portlet renderers
 #